autowisp.database.data_model.target module — AutoWISP documentation

# autowisp.database.data_model.target module

## Class Inheritance Diagram

Define the target table for the pipeline

class autowisp.database.data_model.target.Target(**kwargs)

  Bases: `DataModelBase`

  The table dsecribing the target.

  dec

    The dec of the target

  id

    A unique identifier for each row.

  name

    The name of the target

  notes

    The notes about the target

  observing_sessions
  ra

    The ra of the target

  timestamp

    When record was last changed